@@ -18,10 +18,12 @@
 from .dispatcher import patch_sklearn
 from .dispatcher import unpatch_sklearn
 from .dispatcher import get_patch_names
+from .dispatcher import get_patch_map
 
 __all__ = [
     "patch_sklearn", "unpatch_sklearn", "get_patch_names",
-    "cluster", "decomposition", "ensemble", "linear_model",
+    "get_patch_map", "cluster", "decomposition",
+    "ensemble", "linear_model",
     "manifold", "neighbors", "svm", "metrics",
 ]
 
